@@ -17,21 +17,21 @@ if MainScratch['__tmpstyle__']['__showfigure__']:
     try:
         x = linspace(0, 1, 11)
         y = linspace(0, 1, 101)
-        ybig = y * 10 ** 3  # Make y bigger to test x10^3 axis multiplier stuff
+        ybig = y * 10**3  # Make y bigger to test x10^3 axis multiplier stuff
         fig = OMFITx.Figure(toolbar=False, returnFigure=True, figsize=matplotlib.rcParams['figure.figsize'])
         ax = []
         if MainScratch['__tmpstyle__']['__samplefigmultipanel__']:
             for k in range(1, 4):
-                ax.append(fig.add_subplot(2, 2, k))  # OKadd
+                ax.append(fig.add_subplot(2, 2, k))
                 ax[-1].set_xlabel('$x$')
                 ax[-1].set_ylabel('$y$')
-            ax.append(fig.add_subplot(2, 2, 4, projection='3d'))  # Okadd
+            ax.append(fig.add_subplot(2, 2, 4, projection='3d'))
             ax[-1].set_xlabel('$x$')
             ax[-1].set_ylabel('$y$')
             ax[-1].set_zlabel('$z$')
             fig.suptitle('Suptitle')
         else:
-            ax.append(fig.add_subplot(1, 1, 1))  # OKadd
+            ax.append(fig.add_subplot(1, 1, 1))
             ax[-1].set_xlabel('$x$')
             ax[-1].set_ylabel('$y$')
 
@@ -48,12 +48,12 @@ if MainScratch['__tmpstyle__']['__showfigure__']:
             CS = ax[1].contourf(cos(X) + cos(Y))
             fig.colorbar(CS, ax=ax[1])
             # ax2
-            ax[2].scatter(rand(5) + 10 ** 3, rand(5), c=rand(5))  # Add 10**3 to test offset settings
-            ax[2].errorbar(rand(5) + 10 ** 3, rand(5), rand(5))  # This plot will have an offset (+10^3) with default style
+            ax[2].scatter(rand(5) + 10**3, rand(5), c=rand(5))  # Add 10**3 to test offset settings
+            ax[2].errorbar(rand(5) + 10**3, rand(5), rand(5))  # This plot will have an offset (+10^3) with default style
             # ax3
             theta = np.linspace(-4 * np.pi, 4 * np.pi, 100)
             z = np.linspace(-2, 2, 100)
-            r = z ** 2 + 1
+            r = z**2 + 1
             x = r * np.sin(theta)
             y = r * np.cos(theta)
             ax[3].plot(x, y, z, label='parametric curve')
@@ -171,7 +171,19 @@ OMFITx.Button('Save user style', save_style, updateGUI=True)
 OMFITx.Separator()
 options = SortedDict(sorted=True)
 options.insert(0, '', '')
-for filename, stl in matplotlib.style.core.iter_style_files(os.sep.join([matplotlib.get_configdir(), 'stylelib'])):
+
+
+def iter_style_files(style_dir):
+    """Yield file path and name of styles in the given directory."""
+    for path in os.listdir(style_dir):
+        filename = os.path.basename(path)
+        match = matplotlib.style.core.STYLE_FILE_PATTERN.match(filename)
+        if match is not None:
+            path = os.path.abspath(os.path.join(style_dir, path))
+            yield path, match.group(1)
+
+
+for filename, stl in iter_style_files(os.sep.join([matplotlib.get_configdir(), 'stylelib'])):
     options[stl] = filename
 OMFITx.ComboBox(
     "MainScratch['__tmpstyle__']['__delete__']", options, 'Delete user style', default='', postcommand=delete_style, updateGUI=True
