@@ -494,10 +494,10 @@ class OMFITcheaseLog(SortedDict, OMFITascii):
                             self[name] = ast.literal_eval(line.split()[pos])
         return self
 
-    def read_VacuumMesh(self, npsi):
+    def read_VacuumMesh(self, nv):
         """
         Read vacuum mesh from CHEASE log file
-        :param npsi: number of radial intervals (=NPSI from input namelist)
+        :param nv: number of radial intervals in vacuum (=NV from input namelist)
         """
         self['VACUUM MESH'] = {}
         NW = []
@@ -508,7 +508,7 @@ class OMFITcheaseLog(SortedDict, OMFITascii):
             for line_no, line in enumerate(data):
                 if line.find(mystring) != -1:
                     break
-            for ii in range(npsi + 1):
+            for ii in range(nv + 1):
                 NW.append(int(data[line_no + ii + 1].split()[0]))
                 rw.append(float(data[line_no + ii + 1].split()[1]))
         self['VACUUM MESH']['NW'] = np.asarray(NW)
