@@ -170,7 +170,7 @@ class OMFITcoils(SortedDict, OMFITascii):
                     f, ax = pyplot.subplots(subplot_kw={'projection': projection})
             else:
                 # OMFIT (or the gcf needed to check OMFIT) made a empty figure for us
-                ax = f.add_subplot(111, projection=projection)  # OKadd
+                ax = f.use_subplot(111, projection=projection)
                 try:
                     ax.set_aspect('equal')
                 except NotImplementedError:
