@@ -197,7 +197,7 @@ def importDataset(filename_or_obj=None, complex_dim='i', *args, **kw):
                 del da.attrs[k]
 
     # Deal with illegal characters in names, boolean, and uncertain values
-    for k in list(data.variables.keys()):
+    for k in sorted(list(data.variables.keys())):
         clean_attrs(data[k])
         if k.endswith('__boolean'):
             k = k[: -len('__boolean')]
@@ -206,7 +206,11 @@ def importDataset(filename_or_obj=None, complex_dim='i', *args, **kw):
             del data[k + '__boolean']
         elif k.endswith('__uncertainty'):
             k = k[: -len('__uncertainty')]
-            data[k].values = unumpy.uarray(data[k].values[:], data[k + '__uncertainty'].values[:])
+            a = data[k].values
+            # For some versions of uncertainties/numpy nan uncerainties are not allowed
+            b = data[k + '__uncertainty'].values
+            b[np.where(np.isnan(b))] = 0
+            data[k].values = unumpy.uarray(a[:], b[:])
             del data[k + '__uncertainty']
     for k in list(data.variables.keys()):
         if '_slash_' in k:
