@@ -74,7 +74,7 @@ class OMFITmhdin(OMFITnamelist):
 
                     # number of elements per section
                     nfc = len(self['IN3'].get('FCTURN', self['IN3'].get('TURNFC', None)))
-                    if self['IN3'].get('IECOIL', 0):
+                    if self['IN5'].get('IECOIL', 0):
                         nve = len(self['IN3']['RSISVS'])
                         ntf = len(lines) - nfc - nve
                     else:
@@ -138,7 +138,7 @@ class OMFITmhdin(OMFITnamelist):
                         self['IN3']['ZVS'] = self['VESSEL'][:, 1]
                         self['IN3']['WVS'] = self['VESSEL'][:, 2]
                         self['IN3']['HVS'] = self['VESSEL'][:, 3]
-                        self['IN3']['AVS'] = self['VESSEL'][:, 5]
+                        self['IN3']['AVS'] = self['VESSEL'][:, 4]
                         self['IN3']['AVS2'] = self['VESSEL'][:, 5]
                     if len(self['OH']):
                         self['IN3']['RE'] = self['OH'][:, 0]
@@ -409,7 +409,7 @@ class OMFITmhdin(OMFITnamelist):
         :param ax: axis
         """
 
-        if 'RF' not in self['IN3'] or not hasattr(self['IN3']['RF'], '__len__'):
+        if 'RF' not in self['IN3'] or not hasattr(self['IN3']['RF'], '__len__') or len(self['IN3']['RF']) == 0:
             return
         if ax is None:
             ax = pyplot.gca()
@@ -424,7 +424,7 @@ class OMFITmhdin(OMFITnamelist):
         :param ax: axis
         """
 
-        if 'RE' not in self['IN3'] or not hasattr(self['IN3']['RE'], '__len__'):
+        if 'RE' not in self['IN3'] or not hasattr(self['IN3']['RE'], '__len__') or len(self['IN3']['RE']) == 0:
             return
         if ax is None:
             ax = pyplot.gca()
@@ -438,7 +438,7 @@ class OMFITmhdin(OMFITnamelist):
 
         :param ax: axis
         """
-        if 'RVS' not in self['IN3'] or not hasattr(self['IN3']['RVS'], '__len__'):
+        if 'RVS' not in self['IN3'] or not hasattr(self['IN3']['RVS'], '__len__') or len(self['IN3']['RVS']) == 0:
             return
         if ax is None:
             ax = pyplot.gca()
@@ -505,9 +505,9 @@ class OMFITmhdin(OMFITnamelist):
         from matplotlib import patches
 
         rect = patches.Rectangle(
-            (self['IN3']['RLEFT'], self['IN3']['ZBOTTO']),
-            self['IN3']['RRIGHT'] - self['IN3']['RLEFT'],
-            self['IN3']['ZTOP'] - self['IN3']['ZBOTTO'],
+            (self['IN5']['RLEFT'], self['IN5']['ZBOTTO']),
+            self['IN5']['RRIGHT'] - self['IN5']['RLEFT'],
+            self['IN5']['ZTOP'] - self['IN5']['ZBOTTO'],
             facecolor='none',
             edgecolor='black',
             ls='--',
@@ -713,7 +713,7 @@ class OMFITmhdin(OMFITnamelist):
 
     def fill_scalars_from(self, mhdin):
         """
-        copy scalar quantities in IN3 namelist
+        copy scalar quantities in IN3 and IN5 namelists
         without overwriting ['IFCOIL', 'IECOIL', 'IVESEL']
 
         :param mhdin: other mhdin object
@@ -721,11 +721,18 @@ class OMFITmhdin(OMFITnamelist):
         for item in self['IN3']:
             if item in mhdin['IN3']:
                 if isinstance(mhdin['IN3'][item], (int, float)):
-                    if item not in ['IFCOIL', 'IECOIL', 'IVESEL']:
-                        self['IN3'][item] = mhdin['IN3'][item]
+                    self['IN3'][item] = mhdin['IN3'][item]
                 else:
                     self['IN3'][item] = np.array(self['IN3'][item])
 
+        for item in self['IN5']:
+            if item in mhdin['IN5']:
+                if isinstance(mhdin['IN5'][item], (int, float)):
+                    if item not in ['IFCOIL', 'IECOIL', 'IVESEL']:
+                        self['IN5'][item] = mhdin['IN5'][item]
+                else:
+                    self['IN5'][item] = np.array(self['IN5'][item])
+
     def pretty_print(self, default_tilt2=0):
 
         if 'RF' in self:
@@ -784,7 +791,7 @@ class OMFITmhdin(OMFITnamelist):
 
         a1 = coil_data[4] * np.pi / 180.0
         a2 = coil_data[5] * np.pi / 180.0
-        if a1 < 1e-8:
+        if abs(a1) < 1e-8 and abs(a2) > 1e-8:
             side = coil_data[3] / np.tan(a2)
             hw1 = (coil_data[2] + side) / 2.0
             hw2 = (coil_data[2] - side) / 2.0
@@ -965,7 +972,7 @@ class OMFITmhdin(OMFITnamelist):
 
         return [r, z, w, h, a1, a2]
 
-    # Genirate a mhdin starting
+    # Generate initial mhdin
     def init_mhdin(self, device):
         # mhdin = OMFITnamelist(filename = 'mhdin')
         self['MACHINEIN'] = NamelistName()
@@ -973,30 +980,14 @@ class OMFITmhdin(OMFITnamelist):
         self['MACHINEIN']['nfcoil'] = 1
         self['MACHINEIN']['nfsum'] = 1
         self['MACHINEIN']['nsilop'] = 1
-        self['MACHINEIN']['magpr2'] = 1
+        self['MACHINEIN']['magpri'] = 1
         self['MACHINEIN']['necoil'] = 1
         self['MACHINEIN']['nesum'] = 1
         self['MACHINEIN']['nvesel'] = 1
         self['MACHINEIN']['nvsum'] = 1
         self['MACHINEIN']['nacoil'] = 1
-        self['MACHINEIN']['mgaus1'] = 8
-        self['MACHINEIN']['mgaus2'] = 12
 
         self['IN3'] = NamelistName()
-        self['IN3']['IGRID'] = 1
-        self['IN3']['RLEFT'] = 0.84
-        self['IN3']['RRIGHT'] = 2.54
-        self['IN3']['ZBOTTO'] = -1.6
-        self['IN3']['ZTOP'] = 1.6
-        self['IN3']['IFCOIL'] = 0
-        self['IN3']['ISLPFC'] = 0
-        self['IN3']['NSMP2'] = 25
-        self['IN3']['IECOIL'] = 0
-        self['IN3']['IVESEL'] = 0
-        self['IN3']['IACOIL'] = 0
-        self['IN3']['NW'] = 129
-        self['IN3']['NH'] = 129
-
         self['IN3']['RF'] = []
         self['IN3']['ZF'] = []
         self['IN3']['WF'] = []
@@ -1022,6 +1013,7 @@ class OMFITmhdin(OMFITnamelist):
         self['IN3']['AVS2'] = []
         self['IN3']['RSISVS'] = []
         self['IN3']['VSID'] = []
+        self['IN3']['VSNAME'] = []
 
         self['IN3']['RACOIL'] = []
         self['IN3']['ZACOIL'] = []
@@ -1034,9 +1026,24 @@ class OMFITmhdin(OMFITnamelist):
         #        self['IN3']['HSI'] = []
         #        self['IN3']['AS'] = []
         #        self['IN3']['AS2'] = []
+
+        self['IN5'] = NamelistName()
+        self['IN5']['IGRID'] = 1
+        self['IN5']['RLEFT'] = 0.84
+        self['IN5']['RRIGHT'] = 2.54
+        self['IN5']['ZBOTTO'] = -1.6
+        self['IN5']['ZTOP'] = 1.6
+        self['IN5']['IFCOIL'] = 0
+        self['IN5']['ISLPFC'] = 0
+        self['IN5']['NSMP2'] = 25
+        self['IN5']['IECOIL'] = 0
+        self['IN5']['IVESEL'] = 0
+        self['IN5']['IACOIL'] = 0
+        self['IN5']['mgaus1'] = 8
+        self['IN5']['mgaus2'] = 12
         return self
 
-    def from_omas(self, ods, passive_map='F'):
+    def from_omas(self, ods, passive_map='VS'):
 
         if 'dataset_description.data_entry.machine' in ods:
             device = ods['dataset_description.data_entry.machine']
@@ -1050,27 +1057,39 @@ class OMFITmhdin(OMFITnamelist):
         # DIII-D
         coil_map = {'OH': 'E', 'PF': 'F', 'DIV': 'ACOIL'}
         # ITER
-        coil_map['CS'] = 'F'  # Central solenoid
-        # coil_map['CS'] = 'E' # probably a better choice once operational values are known
-        coil_map['VS'] = passive_map  # Vertical Stabilzation (in-vessel coils)
+        coil_map['CS'] = 'E'  # Central solenoid
+        coil_map['VS'] = 'F'  # Vertical Stabilzation (in-vessel coils)
         coil_map['TF'] = 'ACOIL'  # TF coil busbars
         coil_map['VC'] = 'S'  # Virtual coils (skip)
 
         for coil_type in ['pf_active.coil', 'pf_passive.loop']:
 
+            if not coil_type in ods:
+                continue
+
             for isum in ods[coil_type]:
 
                 coil = ods[coil_type][isum]
-                for i in coil_map.keys():
-                    if i in coil['name']:
-                        efund_name = coil_map[i]
+                efund_name = 'S'
+                if coil_type == 'pf_passive.loop':
+                    efund_name = passive_map
+                else:
+                    for i in coil_map.keys():
+                        if i in coil['name']:
+                            efund_name = coil_map[i]
 
                 if efund_name == 'S':
                     continue
-                elif efund_name == 'VS' and coil_type == 'pf_passive.loop':
-                    self['IN3']['RSISVS'].append(coil['resistivity'])
 
                 nsum[efund_name] += 1
+                if 'CS1L' in coil['name']:  # ITER
+                    nsum[efund_name] -= 1
+                elif efund_name == 'F':
+                    if 'nstx' in device or 'mast' in device:
+                        self['IN3']['TURNFC'].append(1.0)
+                    else:
+                        self['IN3']['TURNFC'].append(coil['element'][0]['turns_with_sign'])
+
                 for ielement in coil['element']:
                     ncoil[efund_name] += 1
                     element = coil['element'][ielement]
@@ -1080,8 +1099,10 @@ class OMFITmhdin(OMFITnamelist):
                         [r, z, w, h, a1, a2] = self.annulus_to_efund(element['geometry.annulus'])
                     elif 'outline' in element['geometry']:
                         [r, z, w, h, a1, a2] = self.outline_to_efund(element['geometry.outline'])
+                    elif 'thick_line' in element['geometry']:
+                        [r, z, w, h, a1, a2] = self.thick_line_to_efund(element['geometry.thick_line'])
                     else:
-                        raise ValueError(f'No conversion defined for geometry of coil {isum}')
+                        raise ValueError(f'No conversion defined for geometry of {coil_type}.{isum}')
 
                     self['IN3'][f'R{efund_name}'].append(r)
                     self['IN3'][f'Z{efund_name}'].append(z)
@@ -1092,18 +1113,27 @@ class OMFITmhdin(OMFITnamelist):
                         self['IN3'][f'A{efund_name}'].append(a1)
                         self['IN3'][f'A{efund_name}2'].append(a2)
 
-                    if efund_name == 'F':
-                        self['IN3'][f'TURN{efund_name}C'].append(1.0)
                     if efund_name == 'VS':
                         self['IN3'][f'VSID'].append(nsum[efund_name])
-                        self['IN3'][f'IVESEL'] = 1
+                        self['IN5'][f'IVESEL'] = 1
+                        if 'resistance' in coil:
+                            self['IN3']['RSISVS'].append(coil['resistance'])
+                        else:
+                            self['IN3']['RSISVS'].append(coil['resistivity'] / 2 / np.pi / r)
+                        self['IN3']['VSNAME'].append(coil['name'])
+                    elif efund_name == 'F':
+                        self['IN3']['FCID'].append(nsum[efund_name])
+                        if 'nstx' in device or 'mast' in device:
+                            self['IN3']['FCTURN'].append(coil['element'][0]['turns_with_sign'])
+                        else:
+                            self['IN3']['FCTURN'].append(1.0)
+                        self['IN5']['IFCOIL'] = 1
                     elif efund_name != 'ACOIL':
                         self['IN3'][f'{efund_name}CID'].append(nsum[efund_name])
-
                         self['IN3'][f'{efund_name}CTURN'].append(coil['element'][0]['turns_with_sign'])
-                        self['IN3'][f'I{efund_name}COIL'] = 1
+                        self['IN5'][f'I{efund_name}COIL'] = 1
                     else:
-                        self['IN3'][f'I{efund_name}'] = 1
+                        self['IN5'][f'I{efund_name}'] = 1
 
         self['MACHINEIN']['nfsum'] = nsum['F']
         self['machinein']['nfcoil'] = ncoil['F']
@@ -1114,9 +1144,10 @@ class OMFITmhdin(OMFITnamelist):
 
         self['MACHINEIN']['nacoil'] = ncoil['ACOIL']
 
+        self['MACHINEIN']['magpri'] = 0
         if 'magnetics' in ods:
             if 'b_field_pol_probe' in ods['magnetics']:
-                self['MACHINEIN']['magpr2'] = nmp2 = len(list(filter(None, ods['magnetics.b_field_pol_probe.:.length'])))
+                self['MACHINEIN']['magpri'] = nmp2 = len(list(filter(None, ods['magnetics.b_field_pol_probe.:.length'])))
                 self['IN3']['XMP2'] = xmp2 = np.zeros(nmp2)
                 self['IN3']['YMP2'] = ymp2 = np.zeros(nmp2)
                 self['IN3']['SMP2'] = smp2 = np.zeros(nmp2)
@@ -1133,32 +1164,25 @@ class OMFITmhdin(OMFITnamelist):
                         mpnam2[n] = probe['name']
                         n += 1
 
+            self['MACHINEIN']['nsilop'] = 0
             if 'flux_loop' in ods['magnetics']:
-                self['MACHINEIN']['nsilop'] = nsilop = len(ods['magnetics.flux_loop'])
+                self['MACHINEIN']['nsilop'] = nsilop = len(
+                    np.where(np.array(list(filter(None, ods['magnetics.flux_loop.:.type.index']))) == 1)[0]
+                )
                 self['IN3']['RSI'] = rsi = np.zeros(nsilop)
                 self['IN3']['ZSI'] = zsi = np.zeros(nsilop)
                 self['IN3']['LPNAME'] = lpname = np.chararray(nsilop, itemsize=10, unicode=True)
                 for i in ods['magnetics.flux_loop']:
                     loop = ods['magnetics.flux_loop'][i]
-                    # this assumes simple loops and
-                    # mean(psi(r1,z1), psi(r2,z2)) = psi(mean(r1, r2), mean(z1, z2))
-                    r = loop['position.0.r']
-                    z = loop['position.0.z']
-                    n = 1
-                    # last position in loop may be repeated
-                    for j in loop['position']:
-                        if loop['position'][j] == loop['position'][0]:
-                            continue
-                        r += loop['position'][j]['r']
-                        z += loop['position'][j]['z']
-                        n += 1
-                    rsi[i] = r / n
-                    zsi[i] = z / n
-                    lpname[i] = loop['name']
+                    if 'type' in loop and 'index' in loop['type'] and loop['type.index'] == 1:
+                        rsi[i] = loop['position.0.r']
+                        zsi[i] = loop['position.0.z']
+                        lpname[i] = loop['name']
 
-        # NOTE: the vacuum vessel could also be described in 'pf_passive' (not yet included)
-        if 'wall.description_2d[0].vessel.unit' in ods:
-            self['IN3']['IVESEL'] = 1
+        # only use vessel described in wall if pf_passive hasn't been already
+        # (these should be equivalent, but the annular wall type is harder to represent)
+        if 'wall.description_2d[0].vessel.unit' in ods and not 'pf_passive.loop' in ods:
+            self['IN5']['IVESEL'] = 1
 
             nvesel = 0
             for i in ods['wall.description_2d.0.vessel.unit']:
@@ -1184,14 +1208,21 @@ class OMFITmhdin(OMFITnamelist):
                 unit = ods['wall.description_2d.0.vessel.unit'][i]
                 if 'element' in unit:
                     rvs[n], zvs[n], wvs[n], hvs[n], avs[n], avs2[n] = self.outline_to_efund(unit['element.0.outline'])
-                    rsisvs[n] = unit['element.0.resistivity']
+                    if 'resistance' in unit['annular.0']:
+                        rsisvs[n] = unit['element.0.resistance']
+                    else:
+                        rsisvs[n] = unit['element.0.resistivity'] / 2 / np.pi / rvs[n]
                     vsid[n] = n + 1
                     vsname[n] = unit['name']
                     n += 1
                 elif 'annular' in unit:
                     nl = n + len(unit['annular.centreline.r']) - 1 + unit['annular.centreline.closed']
                     rvs[n:nl], zvs[n:nl], wvs[n:nl], hvs[n:nl], avs[n:nl], avs2[n:nl] = self.annular_to_efund(unit['annular'])
-                    rsisvs[n:nl] = unit['annular.resistivity']
+                    # IMAS data schema is missing annular resistance...
+                    # if 'resistance' in unit['annular']:
+                    #    rsisvs[n:nl] = unit['annular.resistance']
+                    # else:
+                    rsisvs[n:nl] = unit['annular.resistivity'] / 2 / np.pi / rvs[n:nl]
                     vsid[n:nl] = np.arange(n + 1, nl + 1)
                     vsname[n:nl] = unit['name']
                     n = nl
@@ -1228,6 +1259,30 @@ class OMFITmhdin(OMFITnamelist):
             ods = ODS()
 
         # pf_active
+        if 'pf_active' in update and 'RE' in self['IN3']:
+            r = self['IN3']['RE']
+            z = self['IN3']['ZE']
+            width = self['IN3']['WE']
+            height = self['IN3']['HE']
+            turns = self['IN3']['ECTURN']
+            elements_id = (np.array(self['IN3']['ECID']) - 1).astype(int)
+            rect_code = geo_type_lookup('rectangle', 'pf_active', ods.imas_version, reverse=True)
+            with omas_environment(ods, dynamic_path_creation='dynamic_array_structures'):
+                for i in range(len(r)):
+                    c = elements_id[i]
+                    e = sum(elements_id[:i] == elements_id[i])
+                    ods['pf_active.coil'][c]['name'] = f'OH{c}'
+                    ods['pf_active.coil'][c]['identifier'] = f'OH{c}'
+                    ods['pf_active.coil'][c]['element'][e]['name'] = f'OH{c}_{e}'
+                    ods['pf_active.coil'][c]['element'][e]['identifier'] = f'OH{c}_{e}'
+                    ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i]
+                    rect = ods['pf_active.coil'][c]['element'][e]['geometry.rectangle']
+                    rect['r'] = r[i]
+                    rect['z'] = z[i]
+                    rect['width'] = width[i]
+                    rect['height'] = height[i]
+                    ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = rect_code
+
         if 'pf_active' in update and 'RF' in self['IN3']:
             r = self['IN3']['RF']
             z = self['IN3']['ZF']
@@ -1235,18 +1290,17 @@ class OMFITmhdin(OMFITnamelist):
             height = self['IN3']['HF']
             angle1 = self['IN3']['AF']
             angle2 = self['IN3']['AF2']
-
             turns = self['IN3']['FCTURN']
             if 'TURNFC' in self['IN3']:
                 turnfc = self['IN3']['TURNFC']
             else:
                 turnfc = np.ones(int(max(self['IN3']['FCID'])))
-            elements_id = (self['IN3']['FCID'] - 1).astype(int)
+            elements_id = (np.array(self['IN3']['FCID']) - 1).astype(int)
             rect_code = geo_type_lookup('rectangle', 'pf_active', ods.imas_version, reverse=True)
             outline_code = geo_type_lookup('outline', 'pf_active', ods.imas_version, reverse=True)
-
+            offset = len(ods['pf_active.coil'])
             for i in range(len(r)):
-                c = elements_id[i]
+                c = elements_id[i] + offset
                 e = sum(elements_id[:i] == elements_id[i])
                 ods['pf_active.coil'][c]['name'] = f'PF{c}'
                 ods['pf_active.coil'][c]['identifier'] = f'PF{c}'
@@ -1266,31 +1320,6 @@ class OMFITmhdin(OMFITnamelist):
 
                     ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = outline_code
 
-        if 'pf_active' in update and 'RE' in self['IN3']:
-            r = self['IN3']['RE']
-            z = self['IN3']['ZE']
-            width = self['IN3']['WE']
-            height = self['IN3']['HE']
-            turns = self['IN3']['ECTURN']
-            elements_id = (self['IN3']['ECID'] - 1).astype(int)
-            rect_code = geo_type_lookup('rectangle', 'pf_active', ods.imas_version, reverse=True)
-            offset = len(ods['pf_active.coil'])
-            with omas_environment(ods, dynamic_path_creation='dynamic_array_structures'):
-                for i in range(len(r)):
-                    c = elements_id[i] + offset
-                    e = sum(elements_id[:i] == elements_id[i])
-                    ods['pf_active.coil'][c]['name'] = f'OH{c}'
-                    ods['pf_active.coil'][c]['identifier'] = f'OH{c}'
-                    ods['pf_active.coil'][c]['element'][e]['name'] = f'OH{c}_{e}'
-                    ods['pf_active.coil'][c]['element'][e]['identifier'] = f'OH{c}_{e}'
-                    ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i]
-                    rect = ods['pf_active.coil'][c]['element'][e]['geometry.rectangle']
-                    rect['r'] = r[i]
-                    rect['z'] = z[i]
-                    rect['width'] = width[i]
-                    rect['height'] = height[i]
-                    ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = rect_code
-
         # flux_loop
         if ('magnetics' in update or 'flux_loop' in update) and 'RSI' in self['IN3']:
             R_flux_loop = np.atleast_1d(self['IN3']['RSI'])
@@ -1331,8 +1360,9 @@ class OMFITmhdin(OMFITnamelist):
             height = self['IN3']['HVS']
             angle1 = self['IN3']['AVS']
             angle2 = self['IN3']['AVS2']
-            resistivity = self['IN3']['RSISVS']
-            elements_id = (self['IN3']['VSID'] - 1).astype(int)
+            resistance = self['IN3']['RSISVS']
+            resistivity = np.array(self['IN3']['RSISVS']) * 2 * np.pi * np.array(r)
+            elements_id = (np.array(self['IN3']['VSID']) - 1).astype(int)
 
             for i in range(len(r)):
                 c = elements_id[i]
@@ -1342,6 +1372,7 @@ class OMFITmhdin(OMFITnamelist):
                 ods['pf_passive.loop'][c]['element'][e]['name'] = f'VS{c}_{e}'
                 ods['pf_passive.loop'][c]['element'][e]['identifier'] = f'VS{c}_{e}'
                 ods['pf_passive.loop'][c]['element'][e]['turns_with_sign'] = 1.0
+                ods['pf_passive.loop'][c]['resistance'] = resistance[c]
                 ods['pf_passive.loop'][c]['resistivity'] = resistivity[c]
                 if angle1[i] == 0 and angle2[i] == 0:
                     rect = ods['pf_passive.loop'][c]['element'][e]['geometry.rectangle']
@@ -1366,14 +1397,14 @@ class OMFITmhdin(OMFITnamelist):
         Zf = Zf[1:-1]
 
         # Conservatively set grid to include f-coils (bad idea for tokamak with blanket)
-        self['IN3']['RLEFT'] = np.min(Rf) - 0.5 * wf
-        self['IN3']['RRIGHT'] = np.max(Rf) + 0.5 * wf
-        self['IN3']['ZTOP'] = np.max(Zf) + 0.5 * hf
-        self['IN3']['ZBOTTO'] = np.min(Zf) - 0.5 * hf
+        self['IN5']['RLEFT'] = np.min(Rf) - 0.5 * wf
+        self['IN5']['RRIGHT'] = np.max(Rf) + 0.5 * wf
+        self['IN5']['ZTOP'] = np.max(Zf) + 0.5 * hf
+        self['IN5']['ZBOTTO'] = np.min(Zf) - 0.5 * hf
 
         self['MACHINEIN']['nfsum'] = self['MACHINEIN']['nfcoil'] = nf
 
-        self['IN3']['IFCOIL'] = 1
+        self['IN5']['IFCOIL'] = 1
         self['IN3']['FCID'] = np.arange(1, nf + 1, 1)
         self['IN3']['RF'] = Rf
         self['IN3']['ZF'] = Zf
@@ -1392,7 +1423,7 @@ class OMFITmhdin(OMFITnamelist):
 
         return self
 
-    def fake_geqdsk(self, rbbbs, zbbbs, rlim, zlim, Bt, Ip):
+    def fake_geqdsk(self, rbbbs, zbbbs, rlim, zlim, Bt, Ip, nw, nh):
         """
         This function generates a fake geqdsk that can be used for fixed boundary EFIT modeling
 
@@ -1412,13 +1443,13 @@ class OMFITmhdin(OMFITnamelist):
 
         geqdsk = OMFITgeqdsk('geqdsk')
         geqdsk['CASE'] = ['1', '2', '3', '#999999', '1000ms', '6']
-        geqdsk['NW'] = nw = self['IN3']['NW']
-        geqdsk['NH'] = nh = self['IN3']['NH']
-        geqdsk['RDIM'] = self['IN3']['RRIGHT'] - self['IN3']['RLEFT']
-        geqdsk['ZDIM'] = self['IN3']['ZTOP'] - self['IN3']['ZBOTTO']
-        geqdsk['RLEFT'] = self['IN3']['RLEFT']
-        geqdsk['RCENTR'] = 0.5 * (self['IN3']['RRIGHT'] + self['IN3']['RLEFT'])
-        geqdsk['ZMID'] = 0.5 * (self['IN3']['ZTOP'] + self['IN3']['ZBOTTO'])
+        geqdsk['NW'] = nw
+        geqdsk['NH'] = nh
+        geqdsk['RDIM'] = self['IN5']['RRIGHT'] - self['IN5']['RLEFT']
+        geqdsk['ZDIM'] = self['IN5']['ZTOP'] - self['IN5']['ZBOTTO']
+        geqdsk['RLEFT'] = self['IN5']['RLEFT']
+        geqdsk['RCENTR'] = 0.5 * (self['IN5']['RRIGHT'] + self['IN5']['RLEFT'])
+        geqdsk['ZMID'] = 0.5 * (self['IN5']['ZTOP'] + self['IN5']['ZBOTTO'])
 
         geqdsk['RMAXIS'] = 0.0
         geqdsk['ZMAXIS'] = 0.0
@@ -1476,9 +1507,6 @@ class OMFITdprobe(OMFITmhdin):
                 'AMP2',
                 'SMP2',
                 'PATMP2',
-                'IECOIL',
-                'IVESEL',
-                'IFCOIL',
             ]:
                 del self['IN3'][item]
 
@@ -1651,7 +1679,7 @@ def green_to_omas(
     nw=129,
     nh=129,
     nsilop=44,
-    magpr2=76,
+    magpri=76,
     nesum=6,
     nfsum=18,
     nvsum=24,
@@ -1668,7 +1696,7 @@ def green_to_omas(
 
     :param nw: number of vertical grid points
 
-    :param magpr2: number of magnetic probes (will be overwritten if available in directory)
+    :param magpri: number of magnetic probes (will be overwritten if available in directory)
 
     :param nsilop: number of flux loops (will be overwritten if available in directory)
 
@@ -1691,30 +1719,51 @@ def green_to_omas(
             nfsum = mhdin['machinein']['nfsum']
             nesum = mhdin['machinein']['nesum']
             nvsum = mhdin['machinein']['nvsum']
-            magpr2 = mhdin['machinein']['magpr2']
+            magpri = mhdin['machinein']['magpri']
             nsilop = mhdin['machinein']['nsilop']
     except Exception:
-        filename = '/dprobe.dat'  # pretend dprobe file is mhdin for coil names
-        file = filedir + filename
-        mhdin = OMFITnamelist(file)
-        printw('could not read array sizes from mhdin.dat')
+        try:
+            filename = '/dprobe.dat'  # pretend dprobe file is mhdin for coil names
+            file = filedir + filename
+            mhdin = OMFITnamelist(file)
+            printw('could not read array sizes from mhdin.dat')
+        except Exception:
+            printw('could not read array sizes from mhdin.dat or dprobe.dat')
 
     if ods is None:
         ods = ODS()
 
-    ods['em_coupling.code.name'] = 'EFUND'
-    ods['em_coupling.poloidal_probes'] = mhdin['in3']['mpnam2']
-    ods['em_coupling.flux_loops'] = mhdin['in3']['lpname']
-
     green = {}
     green['nesum'] = nesum
     green['nsilop'] = nsilop
-    green['magpr2'] = magpr2
+    green['magpri'] = magpri
     green['nfsum'] = nfsum
     green['nvsum'] = nvsum
     green['nw'] = nw
     green['nh'] = nh
 
+    ods['em_coupling.code.name'] = 'EFUND'
+    ods['em_coupling.ids_properties.homogeneous_time'] = 2
+
+    # Missing/TODO: These should be setup as URIs now but not sure how to do that... using names or meaningless strings for now
+    if magpri > 0:
+        ods['em_coupling.b_field_pol_probes'] = mhdin['in3']['mpnam2']
+    else:
+        ods['em_coupling.b_field_pol_probes'] = np.empty(0)
+    if nsilop > 0:
+        ods['em_coupling.flux_loops'] = mhdin['in3']['lpname']
+    else:
+        ods['em_coupling.flux_loops'] = np.empty(0)
+    if nesum > 0 or nfsum > 0:
+        ods['em_coupling.active_coils'] = np.chararray(nesum + nfsum, itemsize=1, unicode=True)
+    else:
+        ods['em_coupling.active_coils'] = np.empty(0)
+    if nvsum > 0:
+        ods['em_coupling.passive_loops'] = mhdin['in3']['vsname']
+    else:
+        ods['em_coupling.passive_loops'] = np.empty(0)
+    ods['em_coupling.plasma_elements'] = np.chararray(nw * nh, itemsize=1, unicode=True)
+
     endian = '>'
     # Response of poloidal field (F) coils on grid, and grid on itself.
     filename = f'ec{nw}{nh}.ddd'
@@ -1723,46 +1772,51 @@ def green_to_omas(
     [mw, mh] = f.read_ints(f'{endian}i4')
     grid = f.read_reals(f'{endian}f8')
     green['rgrid'] = grid[:mw]
-    green['zgrid'] = grid[mh:]
+    green['zgrid'] = grid[mw:]
     green['RR'], green['ZZ'] = np.meshgrid(green['rgrid'], green['zgrid'])
+    try:
+        ods['equilibrium.time_slice.0.profiles_2d.0.grid.dim1'] = green['rgrid']
+        ods['equilibrium.time_slice.0.profiles_2d.0.grid.dim2'] = green['zgrid']
+    except Exception:
+        printw('could not write grid sizes to equilibium')
 
     ggridfc = f.read_reals(f'{endian}f8').reshape([nfsum, mw * mh]).T
-    ods['em_coupling.mutual_grid_grid'] = f.read_reals(f'{endian}f8').reshape(mw, mh * mw).T
+    ods['em_coupling.mutual_plasma_plasma'] = f.read_reals(f'{endian}f8').reshape(mw, mh * mw).T
 
     # Response of poloidal field coil on flux loops, magnetic probes, and grid
     filename = f'rfcoil.ddd'
     file = filedir + filename
     f = scipy.io.FortranFile(file, 'r', f'{endian}i4')
     rsilfc = f.read_reals(f'{endian}f8').reshape([nfsum, nsilop]).T
-    rmp2fc = f.read_reals(f'{endian}f8').reshape([nfsum, magpr2]).T
+    rmp2fc = f.read_reals(f'{endian}f8').reshape([nfsum, magpri]).T
 
-    # Response of Ohmic heating coil on flux loops, magnetic probes, and grid
+    # Response of Ohmic heating coil on flux loops, magnetic probes, and plasma
     try:
         filename = f're{nw}{nh}.ddd'
         file = filedir + filename
         f = scipy.io.FortranFile(file, 'r', f'{endian}i4')
         rsilec = f.read_reals(f'{endian}f8').reshape([nesum, nsilop]).T
-        rmp2ec = f.read_reals(f'{endian}f8').reshape([nesum, magpr2]).T
+        rmp2ec = f.read_reals(f'{endian}f8').reshape([nesum, magpri]).T
         gridec = f.read_reals(f'{endian}f8').reshape([nesum, mw * mh]).T
-        ods['em_coupling.mutual_loops_active'] = np.append(rsilfc, rsilec, axis=1)
-        ods['em_coupling.field_probes_active'] = np.append(rmp2fc, rmp2ec, axis=1)
-        ods['em_coupling.mutual_grid_active'] = np.append(ggridfc, gridec, axis=1)
+        ods['em_coupling.mutual_loops_active'] = np.append(rsilec, rsilfc, axis=1)
+        ods['em_coupling.b_field_pol_probes_active'] = np.append(rmp2ec, rmp2fc, axis=1)
+        ods['em_coupling.mutual_plasma_active'] = np.append(gridec, ggridfc, axis=1)
         no_ecoil = False
     except Exception:
         ods['em_coupling.mutual_loops_active'] = rsilfc
-        ods['em_coupling.field_probes_active'] = rmp2fc
-        ods['em_coupling.mutual_grid_active'] = ggridfc
+        ods['em_coupling.b_field_pol_probes_active'] = rmp2fc
+        ods['em_coupling.mutual_plasma_active'] = ggridfc
         no_ecoil = True
         printw('Ohmic heating coil tables not available')
 
-    # Response of vessel on flux loops, probes, and grid
+    # Response of vessel on flux loops, probes, and plasma
     try:
         filename = f'rv{nw}{nh}.ddd'
         file = filedir + filename
         f = scipy.io.FortranFile(file, 'r', f'{endian}i4')
         ods['em_coupling.mutual_loops_passive'] = f.read_reals(f'{endian}f8').reshape([nvsum, nsilop]).T
-        ods['em_coupling.field_probes_passive'] = f.read_reals(f'{endian}f8').reshape([nvsum, magpr2]).T
-        ods['em_coupling.mutual_grid_passive'] = f.read_reals(f'{endian}f8').reshape([nvsum, mw * mh]).T
+        ods['em_coupling.b_field_pol_probes_passive'] = f.read_reals(f'{endian}f8').reshape([nvsum, magpri]).T
+        ods['em_coupling.mutual_plasma_passive'] = f.read_reals(f'{endian}f8').reshape([nvsum, mw * mh]).T
 
     except Exception:
         printw('Vessel not available')
@@ -1773,7 +1827,7 @@ def green_to_omas(
         gecvs = f.read_reals(f'{endian}f8').reshape([nvsum, nesum])
 
         if not no_ecoil:
-            ods['em_coupling.mutual_passive_active'] = np.append(gfcvs, gecvs, axis=1)
+            ods['em_coupling.mutual_passive_active'] = np.append(gecvs, gfcvs, axis=1)
         else:
             ods['em_coupling.mutual_passive_active'] = gfcvs
 
@@ -1782,12 +1836,13 @@ def green_to_omas(
     except Exception:
         printw('Vessel-coil mutual inductances not available')
 
-    # Response of magnetics flux loops and probes on grid
+    # Response of magnetics flux loops and probes on plasma
     filename = f'ep{nw}{nh}.ddd'
     file = filedir + filename
     f = scipy.io.FortranFile(file, 'r', f'{endian}i4')
-    ods['em_coupling.mutual_loops_grid'] = f.read_reals(f'{endian}f8').reshape([mw * mh, nsilop]).T
-    ods['em_coupling.field_probes_grid'] = f.read_reals(f'{endian}f8').reshape([mw * mh, magpr2]).T
+    ods['em_coupling.mutual_loops_plasma'] = f.read_reals(f'{endian}f8').reshape([mw * mh, nsilop]).T
+    ods['em_coupling.b_field_pol_probes_plasma'] = f.read_reals(f'{endian}f8').reshape([mw * mh, magpri]).T
+    ods['em_coupling.ids_properties.homogeneous_time'] = 2
     ods['em_coupling.code.parameters'] = green
     return ods
 
