@@ -17,6 +17,8 @@ from omfit_classes.omfit_ascii import OMFITascii
 import xarray
 import numpy as np
 
+from scipy.interpolate import griddata
+
 __all__ = ['OMFITmars', 'OMFITnColumns', 'OMFITmarsProfile']
 
 
@@ -61,6 +63,9 @@ class OMFITmars(SortedDict, OMFITobject):
                 'FREQUENCIES.OUT',
                 'TIMEEVOL.OUT',
                 'DWK_ENERGY_DENSITY.OUT',
+                'PROFNTV.OUT',
+                'TORQUENTV.OUT',
+                'PROFNUSTAR.OUT',
             ]
             outputs += extra_files
             filename = ','.join([filename + os.sep + x for x in outputs])
@@ -308,7 +313,8 @@ class OMFITmars(SortedDict, OMFITobject):
         :param filename: name of MARS output file, usually PROFEQ.OUT
 
         """
-        mu0 = constants.mu_0
+        from scipy.constants import mu_0
+
         R0 = self[self.sim]['R0EXP'].values.astype(float)
         B0 = self[self.sim]['B0EXP'].values.astype(float)
 
@@ -317,8 +323,8 @@ class OMFITmars(SortedDict, OMFITobject):
         SY = [
             ('s_eq', 's equilibrium (no wall included)', None),
             ('q_prof', 'safety factor', None),
-            ('j_prof', 'current density', B0 / (mu0 * R0)),
-            ('p_prof', 'pressure', B0 * B0 / mu0),
+            ('j_prof', 'current density', B0 / (mu_0 * R0)),
+            ('p_prof', 'pressure', B0 * B0 / mu_0),
             ('n_prof', 'density', None),
             ('v_prof', 'toroidal rotation', None),
             ('eta', 'resistivity=tau_A / tau_R = 1/S', None),
@@ -406,14 +412,15 @@ class OMFITmars(SortedDict, OMFITobject):
         :param NORM: toggle normalization to physical units
         """
         if NORM:
-            mu0 = constants.mu_0
+            from scipy.constants import mu_0
+
             R0 = self[self.sim]['R0EXP'].values.astype(float)
             B0 = self[self.sim]['B0EXP'].values.astype(float)
             TAUA0 = 1.0e-7  # Need to parse log_mars to get TAUA0!
             xnorm = R0 * 1.0e3  # displacement [mm]
             bnorm = B0 * 1.0e4  # b-field [Gauss]
-            cnorm = R0 * B0 / mu0  # current [A]
-            tdnorm = (B0**2) / mu0 / np.pi  # torque density [N/m^2]
+            cnorm = R0 * B0 / mu_0  # current [A]
+            tdnorm = (B0**2) / mu_0 / np.pi  # torque density [N/m^2]
             ttnorm = tdnorm * (R0**3)  # total torque [Nm]
             tmnorm = TAUA0 * 1.0e3  # time [ms]
             unit_t = 'ms'
@@ -563,6 +570,138 @@ class OMFITmars(SortedDict, OMFITobject):
             )
         return
 
+    def read_PROFNTV(self, filename):
+        # commented mu_0 might be needed in future extensions
+        # from scipy.constants import mu_0
+
+        # read data
+        prof = np.loadtxt(filename)
+
+        # profiles
+        rho = prof[:, 0]  # radial coordinate
+        q = prof[:, 1]  # safety factor
+        eps = prof[:, 2]  # equivalent r/R0 in Shaing's theory
+        rhoi = prof[:, 3]  # thermal ion density
+        nu = prof[:, 4]  # collisionality, thermal ion or electron depending on ZCHARGE
+        wti = prof[:, 5]  # thermal ion transit frequency
+        wB0 = prof[:, 6]  # gradB precession drift frequency, depending on ZCHARGE
+        qwe = prof[:, 7]  # ExB drift frequency, =q*omega_E
+        qws = prof[:, 8]  # diamagnetic drift frequency, =q*omega_*p, depending on ZCHARGE
+        qwsT = prof[:, 9]  # grad T drift frequency, =q*omega_*T, depending on ZCHARGE
+        dB = prof[:, 10]  # surface averaged |dB|/B0
+
+        psi = rho**2
+
+        # some fix-ups
+        dB[0] = dB[2]
+        dB[1] = dB[2]
+        """
+        calculate "boundary"-frequencies between different NTV regimes
+        first for non-resonant NTV torque
+                nu < nu_n1 : nu-regime
+        nu_n1 < nu < nu_n2 : sqrt(nu)-regime
+        nu_n2 < nu < nu_n3 : 1/nu-regime
+        nu_n3 < nu         : violation of assumptions in Shaing's NTV theory
+        """
+        nu_n1 = np.abs(qwe / q) * ((dB / eps) ** 2)
+        nu_n2 = np.abs(qwe / q)
+        nu_n3 = np.sqrt(eps) * wti
+
+        """
+        next for resonant NTV torque
+                nu < nu_r1 : superbanana-regime
+        nu_r1 < nu < nu_r2 : superbanana-plateau-regime
+        nu_r2 < nu < nu_r3 : 1/nu-regime
+        nu_r3 < nu         : violation of assumptions in Shaing's NTV theory     
+        """
+        nu_r1 = wB0 * ((dB / eps) ** 1.5)
+        nu_r2 = wB0 / eps
+        nu_r3 = np.sqrt(eps) * wti
+
+        self['PROFNTV'] = xarray.Dataset()
+        self['PROFNTV']['nu_n1'] = xarray.DataArray(
+            nu_n1, dims=['psi'], coords={'psi': psi}, attrs={'Description': 'nu < nu_n1 : nu-regime'}
+        )
+        self['PROFNTV']['nu_n2'] = xarray.DataArray(
+            nu_n2, dims=['psi'], coords={'psi': psi}, attrs={'Description': 'nu_n1 < nu < nu_n2 : sqrt(nu)-regime'}
+        )
+        self['PROFNTV']['nu_n3'] = xarray.DataArray(
+            nu_n3, dims=['psi'], coords={'psi': psi}, attrs={'Description': 'nu_n2 < nu < nu_n3 : 1/nu-regime'}
+        )
+        self['PROFNTV']['nu_r1'] = xarray.DataArray(
+            nu_r1, dims=['psi'], coords={'psi': psi}, attrs={'Description': 'nu < nu_r1 : superbanana-regime'}
+        )
+        self['PROFNTV']['nu_r2'] = xarray.DataArray(
+            nu_r2,
+            dims=['psi'],
+            coords={'psi': psi},
+            attrs={'Description': 'nu_r1 < nu < nu_r2 : superbanana-plateau-regime, nu_r2 < nu < nu_r3 : 1/nu-regime'},
+        )
+        self['PROFNTV']['nu'] = xarray.DataArray(
+            nu, dims=['psi'], coords={'psi': psi}, attrs={'Description': 'collisionality, thermal ion or electron depending on ZCHARGE'}
+        )
+        self['PROFNTV']['eps'] = xarray.DataArray(
+            eps, dims=['psi'], coords={'psi': psi}, attrs={'Description': 'equivalent r/R0 in Shaing theory'}
+        )
+        return
+
+    def read_TORQUENTV(self, filename):
+        """
+        Read TORQUENTV.OUT file containing NTV torque densities
+        """
+        torq = np.loadtxt(filename)
+
+        # get NTV torque densities
+        s = torq[:, 0]  # radial mesh
+        TNTVtot = torq[:, 1]  # total NTV torque density = ions + electrons
+        DPNTVTot = torq[:, 2]  # particle flux due to total NTV torque
+
+        DPNTVi = torq[:, 3]  # particle flux due to ion NTV torque
+        DPNTVe = torq[:, 4]  # particle flux due to electron NTV torque
+
+        TNTVi = torq[:, 5]  # NTV torque due to ions
+        TNTVe = torq[:, 6]  # NTV torque due to electrons
+
+        self['TORQUENTV'] = xarray.Dataset()
+        self['TORQUENTV']['NTV_tot'] = xarray.DataArray(
+            TNTVtot, dims=['s'], coords={'s': s}, attrs={'Description': 'total NTV torque density = ions + electrons'}
+        )
+        self['TORQUENTV']['NTV_ion'] = xarray.DataArray(TNTVi, dims=['s'], coords={'s': s}, attrs={'Description': 'NTV torque due to ions'})
+        self['TORQUENTV']['NTV_el'] = xarray.DataArray(
+            TNTVe, dims=['s'], coords={'s': s}, attrs={'Description': 'NTV torque due to electrons'}
+        )
+
+        # Particle flux
+        self['TORQUENTV']['DP_NTV_tot'] = xarray.DataArray(
+            DPNTVTot, dims=['s'], coords={'s': s}, attrs={'Description': 'particle flux due to total NTV torque'}
+        )
+        self['TORQUENTV']['DP_NTV_ion'] = xarray.DataArray(
+            DPNTVi, dims=['s'], coords={'s': s}, attrs={'Description': 'particle flux due to ion NTV torque'}
+        )
+        self['TORQUENTV']['DP_NTV_el'] = xarray.DataArray(
+            DPNTVe, dims=['s'], coords={'s': s}, attrs={'Description': 'particle flux due to electron NTV torque'}
+        )
+        return
+
+    def read_NUSTAR(self, filename):
+        """
+        Read PROFNUSTAR.OUT file containing ion and electron effective collisionality
+        """
+        # read data
+        nu = np.loadtxt(filename)
+
+        s = nu[:, 0]
+        nui = nu[:, 1]  # nu* ions
+        nue = nu[:, 2]  # nu* electrons
+        self['NUSTAR'] = xarray.Dataset()
+        self['NUSTAR']['nustar_i'] = xarray.DataArray(
+            nui, dims=['s'], coords={'s': s}, attrs={'Description': 'nustar for ions calculated in MARS'}
+        )
+        self['NUSTAR']['nustar_e'] = xarray.DataArray(
+            nue, dims=['s'], coords={'s': s}, attrs={'Description': 'nustar for electrons calculated in MARS'}
+        )
+        return
+
     """
     'get' methods, calculate quantities from previously read data
     """
@@ -932,11 +1071,11 @@ class OMFITmars(SortedDict, OMFITobject):
         dZdchi = self['UnitVector']['dZdchi'].isel(s=range(II))
         R0 = self[self.sim]['R'].isel(s=range(II))
         # Calculate Xr,z,phi
-        Xr = (self['XPLASMA']['X1'].values * dRds.values + self['XPLASMA']['X2'].values * dRdchi.values) / J.values
+        Xr = self['XPLASMA']['X1'].values * dRds.values + self['XPLASMA']['X2'].values * dRdchi.values
         Xr[0:2, :] = Xr[2, :]
-        Xz = (self['XPLASMA']['X1'].values * dZds.values + self['XPLASMA']['X2'].values * dZdchi.values) / J.values
+        Xz = self['XPLASMA']['X1'].values * dZds.values + self['XPLASMA']['X2'].values * dZdchi.values
         Xz[0:2, :] = Xz[2, :]
-        Xphi = (self['XPLASMA']['X3'].values * R0.values) / J.values
+        Xphi = self['XPLASMA']['X3'].values * R0.values
         Xphi[0:2, :] = Xphi[2, :]
         self['XPLASMA']['Xr'] = xarray.DataArray(Xr, dims=['sp', 'chi'], coords={'sp': self['XPLASMA']['sp'], 'chi': self[self.sim]['chi']})
         self['XPLASMA']['Xz'] = xarray.DataArray(Xz, dims=['sp', 'chi'], coords={'sp': self['XPLASMA']['sp'], 'chi': self[self.sim]['chi']})
@@ -1170,6 +1309,9 @@ class OMFITmars(SortedDict, OMFITobject):
                 ('XPLASMA', self.read_XPLASMA),
                 ('FREQUENCIES.OUT', self.read_FREQS),
                 ('DWK_ENERGY_DENSITY.OUT', self.read_dWk_den),
+                ('PROFNTV.OUT', self.read_PROFNTV),
+                ('TORQUENTV.OUT', self.read_TORQUENTV),
+                ('PROFNUSTAR.OUT', self.read_NUSTAR),
             )
         )
         for item in mapper:
@@ -1287,14 +1429,14 @@ class OMFITmars(SortedDict, OMFITobject):
         MM = self[label]['Mm'].values
         labelstring = [str(m) for m in MM]
         for k, c in enumerate(['JM1', 'JM2', 'JM3']):
-            ax = ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
+            ax = ax1 = fig.use_subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['s'], np.real(self[label][c]))
             for i, line in enumerate(ax1.lines):
                 line.set_label(labelstring[i])
             lines1 = ax1.get_lines()
             labelLines(lines1[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax1.set_title('Re($J\cdot j^%d_m$)' % (k + 1), y=0.8)
-            ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
+            ax2 = fig.use_subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['s'], np.imag(self[label][c]))
             for i, line in enumerate(ax2.lines):
                 line.set_label(labelstring[i])
@@ -1346,14 +1488,14 @@ class OMFITmars(SortedDict, OMFITobject):
         MM = self[label]['Mm'].values
         labelstring = [str(m) for m in MM]
         for k, c in enumerate(['BM1', 'BM2', 'BM3']):
-            ax = ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
+            ax = ax1 = fig.use_subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['s'], np.real(self[label][c]))
             for i, line in enumerate(ax1.lines):
                 line.set_label(labelstring[i])
             lines1 = ax1.get_lines()
             labelLines(lines1[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax1.set_title('Re($J\cdot b^%d_m$)' % (k + 1), y=0.8)
-            ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
+            ax2 = fig.use_subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['s'], np.imag(self[label][c]))
             for i, line in enumerate(ax2.lines):
                 line.set_label(labelstring[i])
@@ -1598,7 +1740,7 @@ class OMFITmars(SortedDict, OMFITobject):
             fig = pyplot.figure()
         Ns = self[self.sim]['Ns1'].values
         label = 'XPLASMA'
-        ax = fig.add_subplot(1, 1, 1)
+        ax = fig.use_subplot(1, 1, 1)
         Xr = self[label]['Xr'].isel(sp=range(Ns)).values.real
         # Xz = self[label]['Xz'].isel(sp=range(Ns)).values
         # Xphi = self[label]['Xphi'].isel(sp=range(Ns)).values
@@ -1660,11 +1802,12 @@ class OMFITmars(SortedDict, OMFITobject):
         if NSPECIES > 2:
             SP_DICT = {}
             for II in range(NSPECIES - 2):
-                P = II + NSPECIES - 2
+                #  +2 to skip ions and electrons, +1 to start counting from 1
+                P = II + 2 + 1
                 SP_DICT[P] = [
-                    self['DWK_COMPONENTS']['K_%s_NTD' % P],
-                    self['DWK_COMPONENTS']['K_%s_NTB' % P],
-                    self['DWK_COMPONENTS']['K_%s_NP' % P],
+                    self['DWK_COMPONENTS']['K_%s_NTD' % float(P)],
+                    self['DWK_COMPONENTS']['K_%s_NTB' % float(P)],
+                    self['DWK_COMPONENTS']['K_%s_NP' % float(P)],
                 ]
         x = np.arange(len(labels))
         width = 0.35
@@ -1672,7 +1815,7 @@ class OMFITmars(SortedDict, OMFITobject):
         ax.bar(x + width / 2, electrons, width, label='Electrons')
         if NSPECIES > 2:
             for II in range(NSPECIES - 2):
-                P = II + NSPECIES - 2
+                P = II + 2 + 1
                 ax.bar(x - width / 2, SP_DICT[P], width, label='Specie %s' % P)
         ax.set_ylabel('dWk')
         ax.set_xticks(x)
@@ -1690,28 +1833,28 @@ class OMFITmars(SortedDict, OMFITobject):
         if fig is None:
             fig = pyplot.figure()
         Tw = self['BPLASMA']['Tw']
-        ax1 = fig.add_subplot(3, 2, 1)
+        ax1 = fig.use_subplot(3, 2, 1)
         ax1.plot(Tw * 180 / np.pi, np.real(self['BPLASMA']['Bn_s']), 'b-')
         ax1.set_ylabel('Re(Bn)')
 
-        ax2 = fig.add_subplot(3, 2, 2)
+        ax2 = fig.use_subplot(3, 2, 2)
         ax2.plot(Tw * 180 / np.pi, np.imag(self['BPLASMA']['Bn_s']), 'b-')
         ax2.set_ylabel('Im(Bn)')
 
-        ax3 = fig.add_subplot(3, 2, 3)
+        ax3 = fig.use_subplot(3, 2, 3)
         ax3.plot(Tw * 180 / np.pi, np.real(self['BPLASMA']['Bt_s']), 'b-')
         ax3.set_ylabel('Re(Bt)')
 
-        ax4 = fig.add_subplot(3, 2, 4)
+        ax4 = fig.use_subplot(3, 2, 4)
         ax4.plot(Tw * 180 / np.pi, np.imag(self['BPLASMA']['Bt_s']), 'b-')
         ax4.set_ylabel('Im(Bt)')
 
-        ax5 = fig.add_subplot(3, 2, 5)
+        ax5 = fig.use_subplot(3, 2, 5)
         ax5.plot(Tw * 180 / np.pi, np.real(self['BPLASMA']['Bphi_s']), 'b-')
         ax5.set_ylabel(r'Re($B_{\phi}$)')
         ax5.set_xlabel(r'$\theta$ [$^{\circ}$]')
 
-        ax6 = fig.add_subplot(3, 2, 6)
+        ax6 = fig.use_subplot(3, 2, 6)
         ax6.plot(Tw * 180 / np.pi, np.imag(self['BPLASMA']['Bphi_s']), 'b-')
         ax6.set_ylabel(r'Im($B_{\phi}$)')
         ax6.set_xlabel(r'$\theta$ [$^{\circ}$]')
@@ -1727,33 +1870,33 @@ class OMFITmars(SortedDict, OMFITobject):
         if fig is None:
             fig = pyplot.figure()
         Tw = self['BPLASMA']['Tw']
-        ax1 = fig.add_subplot(3, 2, 1)
+        ax1 = fig.use_subplot(3, 2, 1)
         ax1.plot(self['BPLASMA']['Mm'], np.real(self['BPLASMA']['Bnm_s']), 'bo')
         ax1.set_ylabel(r'$Re(B^m_n)$')
         ax1.grid()
 
-        ax2 = fig.add_subplot(3, 2, 2)
+        ax2 = fig.use_subplot(3, 2, 2)
         ax2.plot(self['BPLASMA']['Mm'], np.imag(self['BPLASMA']['Bnm_s']), 'bo')
         ax2.set_ylabel(r'$Im(B^m_n)$')
         ax2.grid()
 
-        ax3 = fig.add_subplot(3, 2, 3)
+        ax3 = fig.use_subplot(3, 2, 3)
         ax3.plot(self['BPLASMA']['Mm'], np.real(self['BPLASMA']['Btm_s']), 'bo')
         ax3.set_ylabel(r'$Re(B^m_t)$')
         ax3.grid()
 
-        ax4 = fig.add_subplot(3, 2, 4)
+        ax4 = fig.use_subplot(3, 2, 4)
         ax4.plot(self['BPLASMA']['Mm'], np.imag(self['BPLASMA']['Btm_s']), 'bo')
         ax4.set_ylabel(r'$Im(B^m_t)$')
         ax4.grid()
 
-        ax5 = fig.add_subplot(3, 2, 5)
+        ax5 = fig.use_subplot(3, 2, 5)
         ax5.plot(self['BPLASMA']['Mm'], np.real(self['BPLASMA']['Bpm_s']), 'bo')
         ax5.set_ylabel(r'Re($B^m_{\phi}$)')
         ax5.set_xlabel('m')
         ax5.grid()
 
-        ax6 = fig.add_subplot(3, 2, 6)
+        ax6 = fig.use_subplot(3, 2, 6)
         ax6.plot(self['BPLASMA']['Mm'], np.imag(self['BPLASMA']['Bpm_s']), 'bo')
         ax6.set_ylabel(r'Im($B^m_{\phi}$)')
         ax6.set_xlabel('m')
@@ -1881,7 +2024,7 @@ class OMFITmars(SortedDict, OMFITobject):
             Xwr = self['XPLASMA']['Xr'].isel(sp=IIsurf)
             Xwz = self['XPLASMA']['Xz'].isel(sp=IIsurf)
         except IndexError:
-            print('ERROR: Selected index is out of BPLASMA calculation domain')
+            print('ERROR: Selected index is out of XPLASMA calculation domain')
             return
         B0 = self[self.sim]['B0EXP'].values
         R0 = self[self.sim]['R0EXP'].values
@@ -1899,6 +2042,51 @@ class OMFITmars(SortedDict, OMFITobject):
         pyplot.axis('equal')
         pyplot.xlabel('R [m]')
         pyplot.ylabel('Z [m]')
+        return R1, Z1
+
+    def plot_PROFNTV(self, fig=None):
+        """
+        Plot "boundary"-frequencies between different NTV regimes
+        :param fig: specify target figure
+        """
+        from labellines import labelLines
+
+        if fig is None:
+            fig = pyplot.figure()
+        ax = fig.gca()
+        pyplot.semilogy(self['PROFNTV']['psi'], self['PROFNTV']['nu_n1'], 'b:', linewidth=1, label=r'$|\omega_E| (\delta B /\epsilon)^{2}$')
+        pyplot.semilogy(self['PROFNTV']['psi'], self['PROFNTV']['nu_n2'], 'b--', linewidth=2, label=r'$|\omega_E|$')
+        pyplot.semilogy(self['PROFNTV']['psi'], self['PROFNTV']['nu_n3'], 'b-', linewidth=3, label=r'$\sqrt{\epsilon}\omega_{ti}$')
+        pyplot.semilogy(
+            self['PROFNTV']['psi'], self['PROFNTV']['nu_r1'], 'r:', linewidth=1, label=r'$\omega_{B0}(\delta B /\epsilon)^{3/2}$'
+        )
+        pyplot.semilogy(self['PROFNTV']['psi'], self['PROFNTV']['nu_r2'], 'r--', linewidth=2, label=r'$\omega_{B0} / \epsilon$')
+        pyplot.semilogy(self['PROFNTV']['psi'], self['PROFNTV']['nu'] / self['PROFNTV']['eps'], 'k-', linewidth=4, label=r'$\nu /\epsilon$')
+        lines = ax.get_lines()
+        labelLines(lines, yoffsets=0.01, align=False, backgroundcolor="none")
+        pyplot.xlabel(r'$\psi_p$')
+        pyplot.ylabel(r'$freq. / \epsilon$ for NTV regimes [rad/s]')
+
+    def plot_NUSTAR(self, fig=None, kplot=2):
+        """
+        Plot effective collisionality for ions and electrons
+        :param fig: specify target figure
+        :param kplot: =2 to use logscale, =1 to use linear y-axis
+        """
+        from labellines import labelLines
+
+        if fig is None:
+            fig = pyplot.figure()
+        ax = fig.gca()
+        if kplot == 2:
+            pyplot.semilogy(self['NUSTAR']['s'], self['NUSTAR']['nustar_i'], 'r--', linewidth=3, label=r'$\nu^*$ ions')
+            pyplot.semilogy(self['NUSTAR']['s'], self['NUSTAR']['nustar_e'], 'b-', linewidth=3, label=r'$\nu^*$ electrons')
+        else:
+            pyplot.plot(self['NUSTAR']['s'], self['NUSTAR']['nustar_i'], 'r--', linewidth=3, label=r'$\nu^*$ ions')
+            pyplot.plot(self['NUSTAR']['s'], self['NUSTAR']['nustar_e'], 'b-', linewidth=3, label=r'$\nu^*$ electrons')
+        pyplot.xlabel(r'$s=\sqrt{\psi_p}$')
+        pyplot.ylabel(r'$\nu^*$')
+        pyplot.legend(loc=0)
 
 
 class OMFITnColumns(SortedDict, OMFITascii):
@@ -1943,11 +2131,12 @@ class OMFITnColumns(SortedDict, OMFITascii):
         from matplotlib import pyplot
 
         tmp = np.vstack(list(self.values())).T
+        fignum = pyplot.get_fignums()[-1]
         for k in range(tmp.shape[1]):
             # condition to avoid plotting first columnt vs. itself
             if k == 0:
                 continue
-            pyplot.figure(k)
+            pyplot.figure(k + fignum)
             pyplot.plot(tmp[:, 0], tmp[:, k])
             pyplot.ylabel(self._OMFITkeyName)
             pyplot.tight_layout()
