@@ -14,6 +14,7 @@ except ImportError as _excp:
 
 
 from omfit_classes.omfit_data import *
+from omfit_classes.utils_math import *
 from omfit_classes import utils_fusion
 
 try:
@@ -34,6 +35,7 @@ import time
 import numpy as np
 from uncertainties.unumpy import uarray, std_devs, nominal_values
 import weakref
+import xarray
 
 # DIII-D: https://diii-d.gat.com/diii-d/Mdsplusdoc
 # NSTX: http://nstx.pppl.gov/nstx/Software/TDI/TDI_GROUPED.HTML
@@ -52,6 +54,7 @@ __all__ = [
     'OMFITmdsCache',
     'interpret_signal',
     'available_efits_from_mds',
+    'read_vms_date',
 ]
 
 D3D_mds_server_trename_selector = {'': 'atlas', 'lbo': 'orion'}
@@ -295,8 +298,17 @@ def tunneled_MDSserver(MDSserver, quiet=True, forceRemote=False):
         MDSserver_w_tunnel = MDSserver
         if not OMFITaux['MDSserverReachable'][MDSserver0] and tunnel:
             # handle server tunneling (this function does already buffering)
+            try:
+                ssh_path = SERVER['localhost'].get('ssh_path', None)
+            except NameError:
+                ssh_path = None
             username, server, port = setup_ssh_tunnel(
-                assemble_server(username, '', server, port), tunnel, forceTunnel=True, forceRemote=False, allowEmptyServerUsername=True
+                assemble_server(username, '', server, port),
+                tunnel,
+                forceTunnel=True,
+                forceRemote=False,
+                allowEmptyServerUsername=True,
+                ssh_path=ssh_path,
             )
             if not len(username):
                 MDSserver_w_tunnel = '%s:%s' % (server, port)
@@ -619,19 +631,13 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                 if what is not None:
                     if shot is not None:
                         if treename is not None and treename.upper() == 'PTDATA':
-                            printd(
-                                '* Retrieving remote data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post,
-                                topic='MDS',
-                            )
+                            printd('* Retrieving remote data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post, topic='MDS')
                             queryResult = mdsplus_data(
                                 self[mds_connection_cache_ID].get(pre + 'ptdata2("' + signal + '",' + shot + ')' + post, timeout=timeout)
                             )
 
                         elif treename is not None and treename.upper() == 'LOCAL_PTDATA':
-                            printd(
-                                '* Retrieving local data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post,
-                                topic='MDS',
-                            )
+                            printd('* Retrieving local data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post, topic='MDS')
                             queryResult = mdsplus_data(MDSplus.TdiExecute(pre + 'ptdata2("' + signal + '",' + shot + ')' + post))
 
                         elif treename is not None and treename.upper() == 'PSEUDO':
@@ -647,8 +653,7 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                             printd('* Retrieving data ' + pre + 'jet("' + signal + '",' + shot + ')' + post, topic='MDS')
                             queryResult = mdsplus_data(
                                 self[mds_connection_cache_ID].get(
-                                    'ppfuid("' + directory + '");' + pre + 'jet("' + signal + '",' + shot + ')' + post,
-                                    timeout=timeout,
+                                    'ppfuid("' + directory + '");' + pre + 'jet("' + signal + '",' + shot + ')' + post, timeout=timeout
                                 )
                             )
 
@@ -899,6 +904,7 @@ class OMFITmdsConnectionBaseClass(SortedDict):
             try:
                 conn.put(f'{translator(dim)}', txt, *arg)
             except Exception as _excp:
+                print(f'Translator is: {translator(dim)}', txt, *arg)
                 raise _excp.__class__(f'\n\\{dim} {txt}\n' + str(_excp))
 
         # subselect list of quantities from variables
@@ -1674,6 +1680,11 @@ class OMFITmdsValue(dict, OMFITmdsObjects):
         # If treename is not None, data are looked for in MDS and a failure returns data = None.
         # Also check [None], just in case.
         bad_mdsdata = data is None or (len(np.atleast_1d(data)) == 1 and np.atleast_1d(data)[0] is None)
+        # If resampling is used, None can be replaced by 'bad resample signal in'
+        if self.TDI.startswith('resample'):
+            bad_resample = (len(np.atleast_1d(data)) == 1) and (np.atleast_1d(data)[0] == 'bad resample signal in')
+        else:
+            bad_resample = False
 
         if check_dim_of >= 0:
             try:
@@ -1695,10 +1706,12 @@ class OMFITmdsValue(dict, OMFITmdsObjects):
             bad_ptdim = False
             cdim = None
 
+        result = not (bad_mdsdata or bad_resample or bad_ptdata or bad_mdsdim or bad_ptdim)
         if debug:
             return dict(
-                result=not (bad_mdsdata or bad_ptdata or bad_mdsdim or bad_ptdim),
+                result=result,
                 bad_mdsdata=bad_mdsdata,
+                bad_resample=bad_resample,
                 bad_ptdata=bad_ptdata,
                 bad_mdsdim=bad_mdsdim,
                 bad_ptdim=bad_ptdim,
@@ -1709,7 +1722,7 @@ class OMFITmdsValue(dict, OMFITmdsObjects):
                 cdim=cdim,
             )
         else:
-            return not (bad_mdsdata or bad_ptdata or bad_mdsdim or bad_ptdim)
+            return result
 
     def plot(self, *args, **kw):
         """
@@ -1911,6 +1924,26 @@ def get_gas_command_units(shot=None, pointname=None, latex_form=False):
     return 'V'
 
 
+def read_vms_date(vms_timestamp):
+    """
+    Interprets a VMS date
+
+    VMS dates are ticks since 1858-11-17 00:00:00, where each tick is 100 ns
+    Unix ticks are seconds since 1970-01-01 00:00:00 GMT or 1969-12-31 16:00:00
+    This function may be useful because MDSplus dates, at least for KSTAR, are
+    recorded as VMS timestamps, which are not understood by datetime.
+
+    :param vms_timestamp: unsigned int
+
+    :return: datetime.datetime
+    """
+    import datetime
+
+    epoch = 0.0
+    vms_epoc = datetime.datetime.timestamp(datetime.datetime(year=1858, month=11, day=17))
+    return datetime.datetime.fromtimestamp(vms_timestamp / 1e7 - (epoch - vms_epoc))
+
+
 def interpret_signal(server=None, shot=None, treename=None, tdi=None, scratch=None):
     """
     Interprets a signal like abc * def by making multiple MDSplus calls.
