@@ -572,15 +572,15 @@ class OMFITpFile(SortedDict, OMFITascii):
 
         :return: None
         """
-        nplot = len(self)
-        cplot = np.floor(np.sqrt(nplot) / 2.0) * 2
-        rplot = np.ceil(nplot * 1.0 / cplot)
+        nplot = int(len(self))
+        cplot = int(np.floor(np.sqrt(nplot) / 2.0) * 2)
+        rplot = int(np.ceil(nplot * 1.0 / cplot))
         pyplot.subplots_adjust(wspace=0.35, hspace=0.0)
         pyplot.ioff()
         try:
             for k, item in enumerate(self):
-                r = np.floor(k * 1.0 / cplot)
-                c = k - r * cplot
+                r = int(np.floor(k * 1.0 / cplot))
+                c = int(k - r * cplot)
 
                 if k == 0:
                     ax1 = pyplot.subplot(rplot, cplot, r * (cplot) + c + 1)
