@@ -1127,6 +1127,24 @@ class OMFITpythonTask(_OMFITpython):
         kw['noGUI'] = True
         return self.run(**kw)
 
+    def estimate_nprocs_from_available_memory(self):
+        """
+        This method estimates how many prun processes will fit into the memory of the current system.
+        It returns one core less than possible to have a safety margin as processes that do not have
+        enough memory will completely freeze the session.
+        """
+        import psutil
+
+        process = psutil.Process()
+        used_mem = process.memory_info().rss
+        free_mem = psutil.virtual_memory()._asdict()['free']
+        nprocs = (free_mem / used_mem) - 1
+        return nprocs
+
+    def prun_auto_proc(self, nsteps, resultNames, **kw):
+        nprocs = self.estimate_nprocs_from_available_memory()
+        return self.prun(nsteps, nprocs, resultNames, **kw)
+
     def prun(
         self,
         nsteps,
@@ -1148,7 +1166,7 @@ class OMFITpythonTask(_OMFITpython):
 
         :param nsteps: number of calls
 
-        :param nprocs: number of simultaneous processes
+        :param nprocs: number of simultaneous processes; if None, then check SLURM_TASKS_PER_NODE, and then OMP_NUM_THREADS, and finally use 4; the actual number of processors will always be checked against self.estimate_nprocs_from_available_memory and use the that if less
 
         :param resultNames: name, or list of names with the variables that will be returned at the end of the execution of each script
 
@@ -1197,6 +1215,16 @@ class OMFITpythonTask(_OMFITpython):
         else:
             step_label = runlabels
 
+        # set number of processors to reasonable default if not set
+        if nprocs is None:
+            nprocs = int(os.environ.get('SLURM_TASKS_PER_NODE', os.environ.get('OMP_NUM_THREADS', '4')).split(',')[0].split('(')[0])
+
+        max_nprocs = self.estimate_nprocs_from_available_memory()
+        if nprocs > max_nprocs and not bool(os.environ.get('OMFIT_ALLOW_VIRTUAL_MEM', '')):
+            nprocs = max_nprocs
+        if nprocs <= 1:
+            nprocs = 1
+
         # if there are nested parallel loops, make only the outermost parallel
         # if len(OMFITaux['prun_process']):
         #    nprocs=1
@@ -1253,6 +1281,7 @@ class OMFITpythonTask(_OMFITpython):
 
             steps = list(range(nsteps))
             results = result_type()
+            nprocs = int(nprocs)
             step = [None] * nprocs
             p = [None] * nprocs
             p_alive = [0] * nprocs
