@@ -863,7 +863,7 @@ If this file is not available to you contact the GA computer group: iris-support
         # If direct connection fails, use tunneling
         if not OMFITaux['RDBserverReachable'][server] or force_tunnel:
             # Handle server tunneling (this function does already buffering)
-            rdb_server[2:] = list(map(str, setup_ssh_tunnel(server, tunnel, True)))[1:]
+            rdb_server[2:] = list(map(str, setup_ssh_tunnel(server, tunnel, True, ssh_path=SERVER['localhost'].get('ssh_path', None))))[1:]
 
         connection = {}
         if not self.postgresql:
