@@ -1489,6 +1489,9 @@ def manage_tests(
     """
     import astropy.table
     import functools
+    from omfit_classes.utils_base import encrypt, decrypt
+
+    assert decrypt(encrypt('OMFIT')) == 'OMFIT'
 
     # Sanitize
     tests = tolist(tests)  # It's just easier to enter 'Test' than ['Test'] for only one. Let's allow that.
