@@ -295,7 +295,7 @@ class OMFITtranspData(SortedDict):
             if fig.axes:
                 axes = fig.axes[0]
             else:
-                axes = fig.add_subplot(111)
+                axes = fig.use_subplot(111)
         else:
             fig = pyplot.gcf()
             axes = pyplot.gca()
@@ -513,8 +513,8 @@ class OMFITtranspMultigraph(SortedDict):
                 toolbar = NavigationToolbar2(canvas, tab)
                 toolbar.update()
                 canvas._tkcanvas.pack(side='top', fill='both', expand=1)
-                axx = fig.add_subplot(211)  # OKadd
-                axy = fig.add_subplot(212)  # OKadd
+                axx = fig.add_subplot(211)
+                axy = fig.add_subplot(212)
                 tab.fig = fig
 
                 def update_lines(tab, event=None):
@@ -595,7 +595,7 @@ def check_TRANSP_run(runid, project=None, tunnel=None):
 
     socks = {}
     if tunnel is not None:
-        tmp = setup_socks(tunnel)
+        tmp = setup_socks(tunnel, ssh_path=SERVER['localhost'].get('ssh_path', None))
         socks['http'] = 'socks5://localhost:' + tmp[2]
         socks['https'] = 'socks5://localhost:' + tmp[2]
     url = 'https://w3.pppl.gov/cgi-bin/transpgrid_monitor.frames'
@@ -982,7 +982,7 @@ class OMFITplasmastate(OMFITnc):
                         else:
                             prof1d['ion'][ii]['label'] = species
                             prof1d['ion'][ii]['density_thermal'] = self['ns']['data'][ks, :]
-                            prof1d['ion'][ii]['temperature'] = self['Ts']['data'][ks, :]
+                            prof1d['ion'][ii]['temperature'] = self['Ts']['data'][ks, :] * 1e3
                         prof1d['ion'][ii]['element'][0]['z_n'] = list(atomic_element(symbol=prof1d['ion'][ii]['label']).values())[0]['Z']
                         prof1d['ion'][ii]['element'][0]['a'] = list(atomic_element(symbol=prof1d['ion'][ii]['label']).values())[0]['A']
                         prof1d['ion'][ii]['multiple_states_flag'] = 0
