@@ -1034,6 +1034,8 @@ class _SERVER(dict):
                 tmp = evalExpr(OMFIT['MainSettings']['SERVER'][server1])
                 if not isinstance(tmp, namelist.NamelistName) or 'server' not in tmp:
                     continue
+                if tmp['server'] == server0:
+                    return server0, server1
                 known_server = parse_server(tmp['server'])[2]
 
                 if (
@@ -1297,7 +1299,11 @@ def server_picker(root, MainSettings):
         server_picker_cache[device] = 'iris'
     elif is_localhost('omega'):
         server_picker_cache[device] = 'omega'
-    elif is_localhost(['pppl_sunfire', 'nx', 'portal', 'sunfire'], looseCheck=True):
+    elif is_localhost('cori'):
+        server_picker_cache[device] = 'cori'
+    elif is_localhost('perlmutter'):
+        server_picker_cache[device] = 'perlmutter'
+    elif is_localhost(['pppl_sunfire', 'nx', 'portal', 'sunfire', 'transp-srv-stag'], looseCheck=True):
         server_picker_cache[device] = 'portal'
     elif is_localhost(['shenma', 'login110', 'login111', 'login112', 'login113']):
         server_picker_cache[device] = 'shenma'
