@@ -5,6 +5,7 @@ from omfit_classes.omfit_dmp import OMFITdmp
 from omfit_classes.omfit_data import Dataset, DataArray
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from matplotlib.backends._backend_tk import NavigationToolbar2Tk as NavigationToolbar2
+import warnings
 
 # ----------------
 # patch method
@@ -1456,14 +1457,18 @@ Backspace    : Delete selected object
 
     @property
     def active(self):
-        if compare_version(matplotlib.__version__, '3.3.0') >= 0:
+        if compare_version(matplotlib.__version__, '3.4.0') >= 0:
+            return self.toolbar._pan_info
+        elif compare_version(matplotlib.__version__, '3.3.0') >= 0:
             return self.toolbar._button_pressed
         else:
             return self.toolbar._active
 
     @active.setter
     def active(self, value):
-        if compare_version(matplotlib.__version__, '3.3.0') >= 0:
+        if compare_version(matplotlib.__version__, '3.4.0') >= 0:
+            self.toolbar._pan_info = value
+        elif compare_version(matplotlib.__version__, '3.3.0') >= 0:
             self.toolbar._button_pressed = value
         else:
             self.toolbar._active = value
@@ -1636,18 +1641,21 @@ class FigureNotebook(object):
         if isinstance(nfig, str) and not name:
             name = nfig
             nfig = 0
+
         if not len(_active_FigureNotebooks):
             self.num = num = 1
         else:
             self.num = num = max(_active_FigureNotebooks.keys()) + 1
         _active_FigureNotebooks[self.num] = self
         self.figsize = figsize
+
         if OMFITaux['rootGUI'] is None:
             self.master = tk.Tk()
         else:
             self.master = tk.Toplevel(OMFITaux['rootGUI'])
         self.master.withdraw()
         self.master.wm_title(name)
+        self.name = name
         self.master.geometry(geometry)
 
         if OMFITaux['rootGUI'] is not None:
@@ -1672,6 +1680,7 @@ class FigureNotebook(object):
 
         # allow keys to change tabs (ctrl-tab,ctrl-shift-tab)
         self.notebook.enable_traversal()
+        self.notebook.bind('<<NotebookTabChanged>>', self.on_tab_change)
 
         self.master.protocol('WM_DELETE_WINDOW', self.close)
         if OMFITaux['GUI'] is not None:
@@ -1697,6 +1706,18 @@ class FigureNotebook(object):
 
         self.master.deiconify()
 
+    def on_tab_change(self, event=None):
+        tab_num = self.notebook.index(self.notebook.select())
+        if len(self.figures) > tab_num:
+            fig = self.figures.value_for_index(tab_num)
+            pyplot.figure(num=fig.number)
+        else:
+            pass
+
+        # This addresses an issue in which the main window resets the title
+        # This may not happen above matplotlib > 3.3 but it shouldn't hurt anything
+        self.master.wm_title(self.name)
+
     def email(self, event=None):
         try:
             filename = self.canvas.get_default_filename()
@@ -1746,9 +1767,10 @@ class FigureNotebook(object):
         if self.num in _active_FigureNotebooks:
             del _active_FigureNotebooks[self.num]
 
-    def add_figure(self, label="", fig=None, **fig_kwargs):
+    def add_figure(self, label="", num=None, fig=None, **fig_kwargs):
         """
-        Return the figure canvas for the tab with the given label, creating a new tab if that label does not yet exist
+        Return the figure canvas for the tab with the given label, creating a new tab if that label does not yet exist.
+        If fig is passed, then that fig is inserted into the figure.
         """
         # if not in a framework graphical environment, FigureNotebook will simply open new figures
         if OMFITaux['rootGUI'] is None:
@@ -1756,33 +1778,46 @@ class FigureNotebook(object):
                 return fig
             if label == '':
                 label = None
-            fig_kwargs.setdefault('num', label)
+            fig_kwargs['num'] = label if num is None else num
             return pyplot.figure(**fig_kwargs)
 
-        if label in self.figures:
-            return self.figures[label]
-        fig_kwargs['figsize'] = self.figsize
-        tab = tk.Frame(self.notebook)
-        num = fig_kwargs.pop('num', None)
-        if num is not None and label == '':
+        if label and num:  # Implied all three
+            raise RuntimeError("Use only one of label or num or fig")
+
+        if num is not None:
             label = num
+
+        if label in self.figures:
+            fig = self.figures[label]
+            _pylab_helpers.Gcf.set_active(fig.canvas.manager)
+            return fig
+
         if not label and not num:
             label = 'Figure {:}'.format(len(self.figures) + 1)
+        else:
+            pass  # User specified label or num
+
+        figsize = self.figsize
+        tab = tk.Frame(self.notebook)
+
         self.notebook.add(tab, text=label)
         self.notebook.pack()
 
-        # embed the figure - is this the best way to pass the default figsize and kwargs?
         if fig is None:
             fig = Figure(**fig_kwargs)
-        canvas = FigureCanvasTkAgg(fig, master=tab)
-        canvas.draw()
+
+        allnums = pyplot.get_fignums()
+        pyplot_num = max(allnums) + 1 if allnums else 1
+
+        canvas = FigureCanvasTkAgg(figure=fig, master=tab)
+        manager = backend_mod.FigureManagerTk(canvas, pyplot_num, self.master)
+        _pylab_helpers.Gcf._set_new_active_manager(manager)
         fig.set_canvas(canvas)
-        canvas.get_tk_widget().pack(side='top', fill='both', expand=1)
 
         # Add standard toolbar to plot
         toolbar = NavigationToolbar2(canvas, tab)
         toolbar.update()
-        canvas._tkcanvas.pack(side='top', fill='both', expand=1)
+        manager.toolbar = toolbar
 
         # restore default matplotlib hotkeys
         def on_key_press(self, event):
@@ -1809,6 +1844,7 @@ class FigureNotebook(object):
         # Add email button
         bt = tmp._Button(text="Email", file="mail.ppm", command=self.email)
 
+        manager.show()
         return fig
 
     @staticmethod
