@@ -86,7 +86,7 @@ def treeText(inv, strApex=False, n=-1, escape=True):
     elif xarray is not None and isinstance(inv, xarray.Dataset):
         return ', '.join(['%s: %s' % (k, inv.dims[k]) for k in inv.dims])
 
-    elif isinstance(inv, (dict, collections.MutableMapping)):
+    elif isinstance(inv, (dict, collections.abc.MutableMapping)):
         if hasattr(inv, 'dynaLoad') and inv.dynaLoad:
             return '--{\t?\t}--'
 
